@@ -18,7 +18,7 @@ use base qw( FFI::C::Def );
 our @CARP_NOT = qw( FFI::C::Util FFI::C );
 
 # ABSTRACT: Structured data definition for FFI
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 sub _is_kind
@@ -35,6 +35,7 @@ sub new
 
   my %args = %{ delete $self->{args} };
 
+  $self->{trim_string} = delete $args{trim_string} ? 1 : 0;
   my $offset    = 0;
   my $alignment = 0;
   my $anon      = 0;
@@ -100,11 +101,12 @@ sub new
       }
       elsif($self->_is_kind("$spec*", 'record'))
       {
-        $member{spec}   = $spec;
-        $member{rec}    = 1;
-        $member{size}   = $self->ffi->sizeof("$spec*");
         local $@;
-        $member{align}  = eval { $self->ffi->alignof("$spec*") };
+        $member{align}       = eval { $self->ffi->alignof("$spec*") };
+        $member{trim_string} = 1 if $self->{trim_string};
+        $member{spec}        = $spec;
+        $member{rec}         = 1;
+        $member{size}        = $self->ffi->sizeof("$spec*");
         Carp::croak("undefined, or unsupported type: $spec") if $@;
       }
       else
@@ -130,7 +132,7 @@ sub new
     }
   }
 
-  $self->{size} = $offset unless $self->_is_union;
+  $self->{size}        = $offset unless $self->_is_union;
 
   Carp::carp("Unknown argument: $_") for sort keys %args;
 
@@ -178,6 +180,15 @@ sub new
 
           if($self->{members}->{$name}->{rec})
           {
+            if($self->{trim_string})
+            {
+              unless(__PACKAGE__->can('_cast_string'))
+              {
+                $ffi->attach_cast('_cast_string', 'opaque', 'string');
+              }
+              $set = $ffi->function( FFI::C::FFI::memcpy_addr() => ['opaque',$type,'size_t'] => 'string')->sub_ref;
+              $get = \&_cast_string;
+            }
             $code = sub {
               my $self = shift;
               my $ptr = $self->{ptr} + $offset;
@@ -256,6 +267,9 @@ sub new
   $self;
 }
 
+
+sub trim_string { shift->{trim_string} }
+
 1;
 
 __END__
@@ -270,7 +284,7 @@ FFI::C::StructDef - Structured data definition for FFI
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -349,6 +363,11 @@ For standard def options, see L<FFI::C::Def>.
 This should be an array reference containing name, type pairs,
 in the order that they will be stored in the struct.
 
+=item trim_string
+
+If true, fixed-length strings should be treated as null terminated
+strings and be trimmed.
+
 =back
 
 =head1 METHODS
@@ -364,6 +383,13 @@ This creates an instance of the C<struct>, returns a L<FFI::C::Struct>.
 
 You can optionally initialize member values using C<%init>.
 
+=head2 trim_string
+
+ my $bool = $def->trim_string;
+
+Returns true if fixed-length strings should be treated as null terminated
+strings and be trimmed.
+
 =head1 SEE ALSO
 
 =over 4
